@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: configure Dist::Zilla like RUSSOZ
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use Moose 0.99;
 use namespace::autoclean 0.09;
@@ -23,6 +23,13 @@ has twitter => (
     },
 );
 
+has auto_prereqs => (
+    is      => 'ro',
+    isa     => 'Bool',
+    lazy    => 1,
+    default => 1,
+);
+
 has twitter_tags => (
     is      => 'ro',
     isa     => 'Str',
@@ -55,11 +62,12 @@ sub configure {
         ],
 
         'OurPkgVersion',
-        'AutoPrereqs',
 
         'ReportVersions::Tiny',
     );
 
+    $self->add_plugins('AutoPrereqs') if $self->auto_prereqs;
+
     $self->add_bundle(
         'TestingMania' => { disable => q{Test::CPAN::Changes,SynopsisTests}, }
     );
@@ -74,6 +82,7 @@ sub configure {
             }
         ]
     ) if ( $self->twitter );
+
     return;
 }
 
